"""
A module with various plotting utilities
"""
from .plotutils import setfig,plot2dhist
